@@ -139,6 +139,10 @@ pub enum XMLElement {
     PageSize,
     PageMargin,
     WebSettings,
+    HeaderReference,
+    FooterReference,
+    TitlePg,
+    EvenAndOddHeaders,
     Unsupported,
 }
 
@@ -335,6 +339,10 @@ impl FromStr for XMLElement {
             "keepLines" => Ok(XMLElement::KeepLines),
             "pageBreakBefore" => Ok(XMLElement::PageBreakBefore),
             "windowControl" => Ok(XMLElement::WindowControl),
+            "headerReference" => Ok(XMLElement::HeaderReference),
+            "footerReference" => Ok(XMLElement::FooterReference),
+            "titlePg" => Ok(XMLElement::TitlePg),
+            "evenAndOddHeaders" => Ok(XMLElement::EvenAndOddHeaders),
             _ => Ok(XMLElement::Unsupported),
         }
     }
