@@ -5,6 +5,7 @@ pub mod break_type;
 pub mod doc_grid_type;
 pub mod emu;
 pub mod errors;
+pub mod field_char_type;
 pub mod font_pitch_type;
 pub mod height_rule;
 pub mod level_suffix_type;
@@ -30,6 +31,7 @@ pub use break_type::*;
 pub use doc_grid_type::*;
 pub use emu::*;
 pub use errors::*;
+pub use field_char_type::*;
 pub use font_pitch_type::*;
 pub use height_rule::*;
 pub use level_suffix_type::*;
