@@ -61,6 +61,27 @@ impl XMLBuilder {
         self.writer.write(text).expect(EXPECT_MESSAGE);
         self.close()
     }
+
+    pub(crate) fn data_binding(
+        mut self,
+        xpath: Option<&String>,
+        prefix_mappings: Option<&String>,
+        store_item_id: Option<&String>,
+    ) -> Self {
+        let mut e = XmlEvent::start_element("w:dataBinding");
+        if let Some(xpath) = xpath {
+            e = e.attr("w:xpath", xpath);
+        }
+        if let Some(prefix_mappings) = prefix_mappings {
+            e = e.attr("w:prefixMappings", prefix_mappings);
+        }
+        if let Some(store_item_id) = store_item_id {
+            e = e.attr("w:storeItemID", store_item_id);
+        }
+        self.writer.write(e).expect(EXPECT_MESSAGE);
+        self.close()
+    }
+
     // i.e. <w:r ... >
     open!(open_run, "w:r");
     open!(open_run_property, "w:rPr");
@@ -72,6 +93,11 @@ impl XMLBuilder {
     open!(open_paragraph, "w:p", "w14:paraId");
     open!(open_paragraph_property, "w:pPr");
     open!(open_doc_defaults, "w:docDefaults");
+
+    open!(open_structured_tag, "w:sdt");
+    open!(open_structured_tag_content, "w:sdtContent");
+    open!(open_structured_tag_property, "w:sdtPr");
+
     // i.e. <w:outlineLvl ...>
     closed_with_usize!(outline_lvl, "w:outlineLvl");
     // i.e. <w:name ... >
@@ -87,6 +113,10 @@ impl XMLBuilder {
     // i.e. <w:szCs ... >
     closed_with_usize!(sz_cs, "w:szCs");
 
+    closed!(field_character, "w:fldChar", "w:fldCharType", "w:dirty");
+
+    open!(open_instr_text, "w:instrText");
+
     closed_with_str!(text_direction, "w:textDirection");
 
     closed!(b, "w:b");
@@ -277,6 +307,8 @@ impl XMLBuilder {
     closed!(footer_reference, "w:footerReference", "w:type", "r:id");
 
     closed_with_str!(type_tag, "w:type");
+    closed!(title_pg, "w:titlePg");
+    closed!(even_and_odd_headers, "w:evenAndOddHeaders");
     closed!(page_size, "w:pgSz", "w:w", "w:h");
     closed!(page_size_with_orient, "w:pgSz", "w:w", "w:h", "w:orient");
     closed!(
